---------------------------------------------------------
-- RESSOURCE : Random Vehicle Spawn - Airport Wars
-- VERSION : 1.0
-- AUTEURS : Lobix300
--
-- Random vehicle spawner for the Airport Wars server.
---------------------------------------------------------
------------------------------------- VARIABLES ---------------------------------------
local announced = false
local announcedout = false
local randomvehicle = nil
local randomvehiclezone = nil
local isdisablinginprogress = false
---------------------------------------------------------------------------------------


-------------------------------------- FUNCTIONS --------------------------------------
local function CreateZone(x, y, z)
    randomvehiclezone = AddBlipForRadius(x+GetRandomIntInRange(-150, 150), y+GetRandomIntInRange(-150, 150), z, 200.0)
    SetBlipColour(randomvehiclezone, 66)
    SetBlipAlpha(randomvehiclezone, 140)
end

local function AnnounceSpecialDrop(color, title, info)
    CreateThread(function()
        while true do
            Wait(0)
            midsizedmessage = RequestScaleformMovie("MIDSIZED_MESSAGE")
            if not announced then
                while not HasScaleformMovieLoaded(midsizedmessage) do
                    Wait(0)
                end
                BeginScaleformMovieMethod(midsizedmessage, "SHOW_COND_SHARD_MESSAGE")
                BeginTextCommandScaleformString("STRING")
                AddTextComponentScaleform(title)
                EndTextCommandScaleformString()
                BeginTextCommandScaleformString("STRING")
                AddTextComponentScaleform(info)
                EndTextCommandScaleformString()
                PushScaleformMovieMethodParameterInt(color)
                EndScaleformMovieMethodReturn()
                Timera = GetNetworkTime()
                PlaySoundFrontend(-1, "Deliver_Pick_Up", "HUD_FRONTEND_MP_COLLECTABLE_SOUNDS", 1)
                announced = true
            end
            DrawScaleformMovieFullscreen(midsizedmessage, 255, 255, 255, 255)
            if not announcedout then
                if GetTimeDifference(GetNetworkTime(), Timera) > 4000 then
                    BeginScaleformMovieMethod(midsizedmessage, "SHARD_ANIM_OUT")
                    PushScaleformMovieMethodParameterInt(1)
                    PushScaleformMovieMethodParameterFloat(0.33)
                    PopScaleformMovieFunctionVoid()
                    announcedout = true
                end
            end
            if GetTimeDifference(GetNetworkTime(), Timera) > 4500 then
                if HasScaleformMovieLoaded(midsizedmessage) then
                    SetScaleformMovieAsNoLongerNeeded(midsizedmessage)
                    SetTimeout(100, function()
                        announced = false
                        announcedout = false
                    end)
                    return
                end
            end
        end
    end)
end

local function StartPlayerDetection()
    CreateThread(function()
        while true do
            Wait(0)
            while (GetPedInVehicleSeat(randomvehicle, -1) == 0) do
                Wait(0)
            end
            if DoesBlipExist(randomvehiclezone) then
                RemoveBlip(randomvehiclezone)
            end
            return
        end
    end)
end

local function TriggerDisable()
    CreateThread(function()
        isdisablinginprogress = true
        if DoesBlipExist(randomvehiclezone) then
            RemoveBlip(randomvehiclezone)
        end
        SetVehicleDoorsLockedForAllPlayers(randomvehicle, true)
        SetVehicleAsNoLongerNeeded(randomvehicle)
        if (GetPedInVehicleSeat(randomvehicle, -1) == PlayerPedId()) then
            local timer = GetNetworkTime()
            while ((GetPedInVehicleSeat(randomvehicle, -1) == PlayerPedId()) and GetTimeDifference(GetNetworkTime(), timer) < 20000) do
                if GetTimeDifference(GetNetworkTime(), timer) < 5000 then
                    TriggerEvent("airportwars:helptexttimedgxt", "PEG_RECLAIM", -1)
                end
                Wait(0)
            end
            SetVehicleUndriveable(randomvehicle, true)
            randomvehicle = nil
            randomvehiclezone = nil
            isdisablinginprogress = false
            return
        end
    end)
end

local function ForceDelete()
    if DoesBlipExist(randomvehiclezone) then
        RemoveBlip(randomvehiclezone)
    end
    randomvehiclezone = nil
    if DoesEntityExist(randomvehicle) then
        DeleteVehicle(randomvehicle)
    end
    randomvehicle = nil
    isdisablinginprogress = false
end
---------------------------------------------------------------------------------------


-------------------------------------- EVENTS -----------------------------------------
RegisterNetEvent("airportwars:randoms:vehicles:spawn")
AddEventHandler("airportwars:randoms:vehicles:spawn", function(Infos)
    ForceDelete()
    Wait(50)
    RequestModel(Infos.Model)
    while not HasModelLoaded(Infos.Model) do
        Wait(0)
    end
    local randomvehicle = CreateVehicle(Infos.Model, Infos.X, Infos.Y, Infos.Z, Infos.H, true, false)
    local NetID = VehToNet(randomvehicle)
    local Time = GetNetworkTime()
    NetworkRegisterEntityAsNetworked(randomvehicle)
    SetEntitySomething(randomvehicle, true)
    SetNetworkIdExistsOnAllMachines(NetID, true)
    SetEntityAsMissionEntity(randomvehicle)
    SetNetworkIdCanMigrate(NetID, true)
    SetModelAsNoLongerNeeded(Infos.Model)
    TriggerServerEvent("airportwars:randoms:vehicles:spawned", Infos.Model, Infos.X, Infos.Y, Infos.Z, Infos.H, Time, NetID)
end)

RegisterNetEvent("airportwars:randoms:vehicles:triggerspawn")
AddEventHandler("airportwars:randoms:vehicles:triggerspawn", function(model, x, y, z, netid)
    randomvehicle = NetToVeh(netid)
    while (NetToVeh(netid) == 0) do
        Wait(0)
    end
    CreateZone(x, y, z)
    StartPlayerDetection()
    if StartedPlaying then
        AnnounceSpecialDrop(21, "~w~SPECIAL DROP", "A rare "..model.." was dropped on the map ! It's marked on your radars.")
    end
end)

RegisterNetEvent("airportwars:randoms:vehicles:disable")
AddEventHandler("airportwars:randoms:vehicles:disable", function()
    TriggerDisable()
end)
---------------------------------------------------------------------------------------


-------------------------------------- THREADS ----------------------------------------
CreateThread(function()
    while true do
        Wait(0)
        if NetworkIsHost() then
            if ((randomvehicle ~= nil) and not (isdisablinginprogress)) then
                if not IsVehicleDriveable(randomvehicle, true) then
                    TriggerServerEvent("airportwars:randoms:vehicles:destroyed")
                    Wait(30000)
                end
            end
        end
    end
end)

CreateThread(function()
    while true do
        Wait(0)
        if NetworkIsPlayerActive(NetworkPlayerIdToInt()) and NetworkIsSessionStarted() then
            TriggerServerEvent("airportwars:randoms:vehicles:get")
            return
        end
    end
end)
---------------------------------------------------------------------------------------
ready.client_vehicles = true
