---------------------------------------------------------
-- RESSOURCE : Random Vehicle Spawn - Airport Wars
-- VERSION : 1.0
-- AUTEURS : Lobix300
--
-- Random vehicle spawner for the Airport Wars server.
---------------------------------------------------------
------------------------------------- VARIABLES ---------------------------------------
local LastSpawn = 0
local LastDetonate = 0
local SpawnTime = 20
local DeletionTime = 15
local FirstSpawn = true
local VehicleRandomSpawned = false
local HasTriggeredDetonateAnnounce = false
local Infos = {Model = "", X = 0, Y = 0, Z = 0, H = 0, SpawnTime = 0, NetID = 0}
local AirVehiclesList = {"hydra", "buzzard", "hunter"}
local AirVehiclesSpawns = {
  	{x=-2290.677, y=2487.701, z=4.018, h=258.956},
  	{x=-2139.374, y=1993.053, z=191.218, h=138.956},
  	{x=-246.585, y=2185.368, z=130.318, h=183.956},
  	{x=796.708, y=2254.278, z=48.418, h=238.956},
  	{x=1740.528, y=3263.87, z=43.918, h=103.956},
  	{x=1090.069, y=141.878, z=88.018, h=138.956},
  	{x=341.12, y=-497.022, z=37.618, h=83.956},
  	{x=-245.104, y=-1188.638, z=40.318, h=96.456},
  	{x=-960.318, y=-1322.513, z=56.518, h=146.456},
  	{x=-1033.652, y=-2633.248, z=41.218, h=341.456},
  	{x=-333.148, y=-2677.125, z=11.518, h=148.956},
  	{x=918.536, y=-3327.972, z=7.918, h=63.956},
  	{x=1080.41, y=-1692.158, z=32.218, h=3.956},
  	{x=-480.968, y=1522.98, z=397.418, h=331.456},
  	{x=-412.231, y=1173.039, z=327.718, h=281.456},
  	{x=-761.788, y=1581.689, z=215.718, h=188.956}
}
---------------------------------------------------------------------------------------


-------------------------------------- FUNCTIONS --------------------------------------
local function GetSpawnTime()
    return math.floor(SpawnTime*60000)
end

local function GetDeletionTime()
    return math.floor(DeletionTime*60000)
end

local function IsFirstSpawn()
		return FirstSpawn
end

local function IsVehicleRandomSpawned()
    return VehicleRandomSpawned
end

local function GetRandomVehicle()
    local RandomVehicleModel = AirVehiclesList[math.random(1, Count(AirVehiclesList))]
    local RandomVehicleLocation = AirVehiclesSpawns[math.random(1, Count(AirVehiclesSpawns))]
		local Vehicle = {Model = RandomVehicleModel, X = RandomVehicleLocation.x, Y = RandomVehicleLocation.y, Z = RandomVehicleLocation.z, H = RandomVehicleLocation.h}
    return Vehicle
end

local function ConfirmSpawn(model, x, y, z, h, time, netid)
		Infos.Model, Infos.X, Infos.Y, Infos.Z, Infos.H, Infos.SpawnTime, Infos.NetID = model, x, y, z, h, time, netid
		HasTriggeredDetonateAnnounce = false
		VehicleRandomSpawned = true
		LastSpawn = GetGameTimer()
		TriggerClientEvent("airportwars:randoms:vehicles:triggerspawn", -1, UpperFirstLetter(model), x, y, z, netid)
		SendDiscordMessage("A rare "..UpperFirstLetter(model).." was dropped on the map. It has been marked on your radars! (available for "..tostring(DeletionTime).." mins)", true)
end

local function GetLastSpawnNetworkTime()
		return LastSpawn
end

local function GetLastDetonateNetworkTime()
		return LastDetonate
end

local function TriggeredDetonateAnnounce()
		return HasTriggeredDetonateAnnounce
end

local function ResetInfos()
		Infos = {Model = "", X = 0, Y = 0, Z = 0, H = 0, SpawnTime = 0, NetID = 0}
end
---------------------------------------------------------------------------------------


-------------------------------------- EVENTS -----------------------------------------
RegisterServerEvent("airportwars:randoms:vehicles:spawned")
AddEventHandler("airportwars:randoms:vehicles:spawned", function(model, x, y, z, h, time, netid)
		ConfirmSpawn(model, x, y, z, h, time, netid)
end)

RegisterServerEvent("airportwars:randoms:vehicles:destroyed")
AddEventHandler("airportwars:randoms:vehicles:destroyed", function()
    TriggerClientEvent("airportwars:simplenotify", -1, "SPCL_VEH_DSTR", -1, {UpperFirstLetter(Infos.Model)}, true)
    SendDiscordMessage("The special **"..UpperFirstLetter(Infos.Model).."** has been destroyed.", true)
    TriggerClientEvent("airportwars:randoms:vehicles:disable", -1, Infos.NetID)
    ResetInfos()
    VehicleRandomSpawned = false
    HasTriggeredDetonateAnnounce = false
    LastDetonate = GetGameTimer()
end)
---------------------------------------------------------------------------------------


-------------------------------------- THREADS ----------------------------------------
CreateThread(function()
    AirportWarsThread(30, function()
      	if (GetHostId() ~= nil) then
    				if not IsVehicleRandomSpawned() then
    						if not IsFirstSpawn() then
    								if GetGameTimer() >= GetLastDetonateNetworkTime() + GetSpawnTime() then
    										TriggerClientEvent("airportwars:randoms:vehicles:spawn", GetHostId(), GetRandomVehicle())
    								end
    						else
    								LastDetonate = GetGameTimer() + (GetSpawnTime()/2.5)
    								FirstSpawn = false
    						end
    				end
    		end
    end)
end)

CreateThread(function()
    AirportWarsThread(1, function()
      	if IsVehicleRandomSpawned() then
    				if GetGameTimer() - GetLastSpawnNetworkTime() >= GetDeletionTime() - 120000 and not TriggeredDetonateAnnounce() then
    						TriggerClientEvent("airportwars:simplenotify", -1, "SPCL_VEH_DSTR_IN_2", -1, {UpperFirstLetter(Infos.Model)}, true)
    						HasTriggeredDetonateAnnounce = true
    				end
    				if GetGameTimer() - GetLastSpawnNetworkTime() >= GetDeletionTime() then
    						TriggerClientEvent("airportwars:simplenotify", -1, "SPCL_VEH_DSTRED", -1, {UpperFirstLetter(Infos.Model), tostring(DeletionTime)}, true)
                SendDiscordMessage("The special **"..UpperFirstLetter(Infos.Model).."** has detonated after "..tostring(DeletionTime).." minutes.", true)
    						TriggerClientEvent("airportwars:randoms:vehicles:disable", -1, Infos.NetID)
    						ResetInfos()
    						VehicleRandomSpawned = false
    						HasTriggeredDetonateAnnounce = false
                LastDetonate = GetGameTimer()
    				end
    		end
    end)
end)
---------------------------------------------------------------------------------------
